#
# spec file for package python-boolean.py
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-boolean.py
Version:        4.0
Release:        1.10
Summary:        Module to define boolean algebras and create/parse boolean expressions
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/bastikr/boolean.py
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
"boolean.py" is a library implementing a boolean algebra. It defines
two base elements, TRUE and FALSE, and a Symbol class that can take on one of
these two values. Calculations are done in terms of AND, OR and NOT - other
compositions like XOR and NAND are not implemented but can be emulated with
AND or and NOT. Expressions are constructed from parsed strings or in Python.

%prep
%setup -q -n boolean.py-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
sphinx-build docs html
rm -rf html/.{doctrees,buildinfo}

%check
%pyunittest discover -v

%files %{python_files}
%license LICENSE.txt
%doc README.rst CHANGELOG.rst html/
%{python_sitelib}/*

%changelog
* Thu Sep 22 2022 Matthias Fehring <buschmann23@opensuse.org>
- update to 4.0
  * API changes
    + Drop support for Python 2.
    + Test on Python 3.10
    + Make Expression.sort_order an instance attributes and not a
    class attribute
  * Misc.
    + Correct licensing documentation
    + Improve docstringf and apply minor refactorings
    + Adopt black code style and isort for imports
* Mon Sep  6 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Thu Jan 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 3.7
  * Add new sort argument to simplify() to optionally not sort when
    simplifying expressions (e.g. not applying "commutativity").
  * Add new argument to tokenizer to optionally accept extra
    characters in symbol tokens.
* Tue Sep 10 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Thu Sep  5 2019 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- New package, version 3.6
